Description: Bittorrent Meta File Creator.

# TorrentFile

## :globe_with_meridians: Overview

A `simple` and `convenient` tool for creating, reviewing, editing, and/or
checking/validating bittorrent meta files (aka torrent files). `torrentfile`
supports all versions of Bittorrent files, including hybrid meta files.

> A GUI frontend for this project can be found at https://github.com/alexpdev/TorrentfileQt

## :white_check_mark: Requirements

- Python 3.7+
- Tested on Linux and Windows

## :package: Install

via PyPi:

    pip install torrentfile

via Git:

    git clone https://github.com/alexpdev/torrentfile.git
    python setup.py install

> Download pre-compiled binaries from the release page.

## :scroll: Documentation

Documentation can be found here or in the `docs` directory.

## :rocket: Usage

    torrentfile [-h] [-i] [-V] [-v]  ...

    Sub-Commands:

        create           Create a new torrent file.
        check            Check if file/folder contents match a torrent file.
        edit             Edit a pre-existing torrent file.

    optional arguments:
      -h, --help         show this help message and exit
      -V, --version      show program version and exit
      -i, --interactive  select program options interactively
      -v, --verbose      output debug information

> Usage examples can be found in the project documentation on the examples page.

## :memo: License

Distributed under the GNU LGPL v3. See `LICENSE` for more information.

## :bug: Issues

If you encounter any bugs or would like to request a new feature please open a new issue.

https://github.com/alexpdev/torrentfile/issues